<?php

namespace FiloBlu\GuestWishlist\Controller\Index;

use Magento\Customer\Model\Session as CustomerSession;
use Magento\Framework\Exception\NotFoundException;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\App\RequestInterface;
use Magento\Framework\App\Response\RedirectInterface;

class Plugin
{
    /**
     * @var \FiloBlu\GuestWishlist\Helper\Data
     */
    private $_helper;

    /**
     * @var \Magento\Framework\App\Response\Http
     */
    private $response;

    /**
     * @var \Magento\Wishlist\Model\AuthenticationStateInterface
     */
    private $authenticationState;

    /**
     * @var RedirectInterface
     */
    private $redirector;

    /**
     * @var ScopeConfigInterface
     */
    private $config;

    /**
     * @var CustomerSession
     */
    private $customerSession;

    /**
     * @param CustomerSession $customerSession
     * @param \Magento\Wishlist\Model\AuthenticationStateInterface $authenticationState
     * @param ScopeConfigInterface $config
     * @param RedirectInterface $redirector
     * @param \FiloBlu\GuestWishlist\Helper\Data $helper
     * @param \Magento\Framework\App\Response\Http $response
     */
    public function __construct(
        CustomerSession $customerSession,
        \Magento\Wishlist\Model\AuthenticationStateInterface $authenticationState,
        ScopeConfigInterface $config,
        RedirectInterface $redirector,
        \FiloBlu\GuestWishlist\Helper\Data $helper,
        \Magento\Framework\App\Response\Http $response
    ) {
        $this->_helper = $helper;
        $this->response = $response;
        $this->customerSession = $customerSession;
        $this->authenticationState = $authenticationState;
        $this->redirector = $redirector;
        $this->config = $config;
    }

    /**
     * Perform customer authentication and wishlist feature state checks
     *
     * @param \Magento\Framework\App\ActionInterface $subject
     * @param RequestInterface $request
     * @return void
     * @throws NotFoundException
     * @throws \Magento\Framework\Exception\SessionException
     */
    public function beforeDispatch(\Magento\Framework\App\ActionInterface $subject, RequestInterface $request)
    {
        # Avoid redirect to login for guest wishlist
        if (!$this->_helper->getConfig("general/enabled") && $this->authenticationState->isEnabled() && !$this->customerSession->authenticate()) {
            $subject->getActionFlag()->set('', 'no-dispatch', true);
            if (!$this->customerSession->getBeforeWishlistUrl()) {
                $this->customerSession->setBeforeWishlistUrl($this->redirector->getRefererUrl());
            }
            $this->customerSession->setBeforeWishlistRequest($request->getParams());
            $this->customerSession->setBeforeRequestParams($this->customerSession->getBeforeWishlistRequest());
            $this->customerSession->setBeforeModuleName('wishlist');
            $this->customerSession->setBeforeControllerName('index');
            $this->customerSession->setBeforeAction('add');
        }
        if (!$this->config->isSetFlag('wishlist/general/active')) {
            throw new NotFoundException(__('Page not found.'));
        }
    }
}
