<?php

namespace FiloBlu\GuestWishlist\Controller\Plugin;

use Magento\Framework\Controller\ResultFactory;
use Magento\Catalog\Api\ProductRepositoryInterface;


class Add {

    /**
     * @var \Magento\Framework\Controller\Result\JsonFactory
     */
    private $resultJsonFactory;
    /**
     * @var \Magento\Framework\Message\ManagerInterface
     */
    private $messageManager;
    /**
     * @var \Magento\Framework\App\RequestInterface
     */
    private $request;
    /**
     * @var \Magento\Framework\Controller\Result\Redirect
     */
    private $resultFactory;
    /**
     * @var \Magento\Framework\Data\Form\FormKey\Validator
     */
    private $formKeyValidator;
    /**
     * @var ProductRepositoryInterface
     */
    private $productRepository;

    /**
     * @param \Magento\Framework\Controller\Result\JsonFactory $resultJsonFactory
     * @param \Magento\Framework\Message\ManagerInterface $messagesManager
     * @param \Magento\Framework\App\RequestInterface $request
     * @param \Magento\Framework\Controller\Result\Redirect $resultRedirect
     * @param \Magento\Framework\Data\Form\FormKey\Validator $formKeyValidator
     * @param ProductRepositoryInterface $productRepository
     */
    public function __construct(
        \Magento\Framework\Controller\Result\JsonFactory $resultJsonFactory,
        \Magento\Framework\Message\ManagerInterface $messagesManager,
        \Magento\Framework\App\RequestInterface $request,
        \Magento\Framework\Controller\Result\Redirect $resultRedirect,
        \Magento\Framework\Data\Form\FormKey\Validator $formKeyValidator,
        ProductRepositoryInterface $productRepository
    ) {
        $this->resultJsonFactory = $resultJsonFactory;
        $this->messageManager = $messagesManager;
        $this->request = $request;
        $this->resultFactory = $resultRedirect;
        $this->formKeyValidator = $formKeyValidator;
        $this->productRepository = $productRepository;
    }

    public function afterExecute($object, $resultPage) {

        if(!$this->request->isXmlHttpRequest()) {
            return $resultPage;
        }

        $requestParams = $this->request->getParams();

        $resultJson = $this->resultJsonFactory->create();

        $productId = isset($requestParams['product']) ? (int)$requestParams['product'] : null;

        try {
            $product = $this->productRepository->getById($productId);
        } catch (NoSuchEntityException $e) {
            $product = null;
        }

        if (!$productId) {
            $resultRedirect->setPath('*/');
            return $resultRedirect;
        }

        return $resultJson->setData([
                'product_sku' => $product->getSku()
        ]);

    }

}
