<?php

/**
 * Copyright © Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */

namespace FiloBlu\GuestWishlist\Setup;

use Magento\Framework\DB\Ddl\Table;
use Magento\Framework\Setup\ModuleContextInterface;
use Magento\Framework\Setup\SchemaSetupInterface;
use Magento\Framework\Setup\InstallSchemaInterface;


/**
 * @codeCoverageIgnore
 */
class Recurring implements InstallSchemaInterface {


    /**
     * {@inheritdoc}
     */
    public function install(SchemaSetupInterface $setup, ModuleContextInterface $context) {

        $setup->startSetup();

        # Edit db for consistency of data
        $connection = $setup->getConnection();

        $connection->dropForeignKey($setup->getTable("wishlist"), 'WISHLIST_CUSTOMER_ID_CUSTOMER_ENTITY_ENTITY_ID');

        if ($connection->tableColumnExists('wishlist', 'customer_id')) {
            $definition = [
                'type' => Table::TYPE_INTEGER,
                'nullable' => true,
                'comment' => 'Customer ID',
                'unsigned' => true
            ];
            $connection->modifyColumn(
                    $setup->getTable('wishlist'), 'customer_id', $definition
            );
        }

        $tableName = $setup->getTable('wishlist');
        $columnName = 'cookie';

        if ($connection->tableColumnExists($tableName, $columnName) === false) {

            $connection->addColumn($tableName, $columnName, array(
                'type' => Table::TYPE_TEXT,
                'length' => 32,
                'default' => '',
                'comment' => 'Cookie reference'
            ));
        }

        // Update table wishlist to set again customer id = NULL when 0
        $connection->update($connection->getTableName('wishlist'),['customer_id' => NULL],$connection->quoteInto('customer_id = ?', 0));

        $setup->endSetup();
    }

}